From ed30c60150ffda0301eb1f8d30c93cac94de41df Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Mon, 25 Jul 2011 10:38:22 -0400
Subject: [PATCH] Fixed some warnings in the installer.
---
interface/web/mail/mail_user_stats.php | 15 ++++++---------
1 files changed, 6 insertions(+), 9 deletions(-)
diff --git a/interface/web/mail/mail_user_stats.php b/interface/web/mail/mail_user_stats.php
index ad431e9..c501a86 100644
--- a/interface/web/mail/mail_user_stats.php
+++ b/interface/web/mail/mail_user_stats.php
@@ -12,11 +12,8 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'mail')) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('mail');
$app->load('listform_actions');
@@ -36,22 +33,22 @@
//** Traffic of the current month
$tmp_date = date('Y-m');
$tmp_rec = $app->db->queryOneRecord("SELECT traffic as t FROM mail_traffic WHERE mailuser_id = ".$rec['mailuser_id']." AND month = '$tmp_date'");
- $rec['this_month'] = number_format(intval($tmp_rec['t'])/1024, 0, '.', ' ');
+ $rec['this_month'] = number_format(intval($tmp_rec['t'])/1024/1024, 0, '.', ' ');
//** Traffic of the current year
$tmp_date = date('Y');
$tmp_rec = $app->db->queryOneRecord("SELECT sum(traffic) as t FROM mail_traffic WHERE mailuser_id = ".$rec['mailuser_id']." AND month like '$tmp_date%'");
- $rec['this_year'] = number_format(intval($tmp_rec['t'])/1024, 0, '.', ' ');
+ $rec['this_year'] = number_format(intval($tmp_rec['t'])/1024/1024, 0, '.', ' ');
//** Traffic of the last month
$tmp_date = date('Y-m',mktime(0, 0, 0, date("m")-1, date("d"), date("Y")));
$tmp_rec = $app->db->queryOneRecord("SELECT traffic as t FROM mail_traffic WHERE mailuser_id = ".$rec['mailuser_id']." AND month = '$tmp_date'");
- $rec['last_month'] = number_format(intval($tmp_rec['t'])/1024, 0, '.', ' ');
+ $rec['last_month'] = number_format(intval($tmp_rec['t'])/1024/1024, 0, '.', ' ');
//** Traffic of the last year
$tmp_date = date('Y',mktime(0, 0, 0, date("m"), date("d"), date("Y")-1));
$tmp_rec = $app->db->queryOneRecord("SELECT sum(traffic) as t FROM mail_traffic WHERE mailuser_id = ".$rec['mailuser_id']." AND month like '$tmp_date%'");
- $rec['last_year'] = number_format(intval($tmp_rec['t'])/1024, 0, '.', ' ');
+ $rec['last_year'] = number_format(intval($tmp_rec['t'])/1024/1024, 0, '.', ' ');
//* The variable "id" contains always the index variable
$rec['id'] = $rec[$this->idx_key];
--
Gitblit v1.9.1